[−][src]Enum unicode_types::linear_a::LinearA
An enum to represent all characters in the LinearA block.
Variants
SignAb001\u{10600}: '𐘀'
SignAb002\u{10601}: '𐘁'
SignAb003\u{10602}: '𐘂'
SignAb004\u{10603}: '𐘃'
SignAb005\u{10604}: '𐘄'
SignAb006\u{10605}: '𐘅'
SignAb007\u{10606}: '𐘆'
SignAb008\u{10607}: '𐘇'
SignAb009\u{10608}: '𐘈'
SignAb010\u{10609}: '𐘉'
SignAb011\u{1060a}: '𐘊'
SignAb013\u{1060b}: '𐘋'
SignAb016\u{1060c}: '𐘌'
SignAb017\u{1060d}: '𐘍'
SignAb020\u{1060e}: '𐘎'
SignAb021\u{1060f}: '𐘏'
SignAb021f\u{10610}: '𐘐'
SignAb021m\u{10611}: '𐘑'
SignAb022\u{10612}: '𐘒'
SignAb022f\u{10613}: '𐘓'
SignAb022m\u{10614}: '𐘔'
SignAb023\u{10615}: '𐘕'
SignAb023m\u{10616}: '𐘖'
SignAb024\u{10617}: '𐘗'
SignAb026\u{10618}: '𐘘'
SignAb027\u{10619}: '𐘙'
SignAb028\u{1061a}: '𐘚'
SignA028b\u{1061b}: '𐘛'
SignAb029\u{1061c}: '𐘜'
SignAb030\u{1061d}: '𐘝'
SignAb031\u{1061e}: '𐘞'
SignAb034\u{1061f}: '𐘟'
SignAb037\u{10620}: '𐘠'
SignAb038\u{10621}: '𐘡'
SignAb039\u{10622}: '𐘢'
SignAb040\u{10623}: '𐘣'
SignAb041\u{10624}: '𐘤'
SignAb044\u{10625}: '𐘥'
SignAb045\u{10626}: '𐘦'
SignAb046\u{10627}: '𐘧'
SignAb047\u{10628}: '𐘨'
SignAb048\u{10629}: '𐘩'
SignAb049\u{1062a}: '𐘪'
SignAb050\u{1062b}: '𐘫'
SignAb051\u{1062c}: '𐘬'
SignAb053\u{1062d}: '𐘭'
SignAb054\u{1062e}: '𐘮'
SignAb055\u{1062f}: '𐘯'
SignAb056\u{10630}: '𐘰'
SignAb057\u{10631}: '𐘱'
SignAb058\u{10632}: '𐘲'
SignAb059\u{10633}: '𐘳'
SignAb060\u{10634}: '𐘴'
SignAb061\u{10635}: '𐘵'
SignAb065\u{10636}: '𐘶'
SignAb066\u{10637}: '𐘷'
SignAb067\u{10638}: '𐘸'
SignAb069\u{10639}: '𐘹'
SignAb070\u{1063a}: '𐘺'
SignAb073\u{1063b}: '𐘻'
SignAb074\u{1063c}: '𐘼'
SignAb076\u{1063d}: '𐘽'
SignAb077\u{1063e}: '𐘾'
SignAb078\u{1063f}: '𐘿'
SignAb079\u{10640}: '𐙀'
SignAb080\u{10641}: '𐙁'
SignAb081\u{10642}: '𐙂'
SignAb082\u{10643}: '𐙃'
SignAb085\u{10644}: '𐙄'
SignAb086\u{10645}: '𐙅'
SignAb087\u{10646}: '𐙆'
SignA100Dash102\u{10647}: '𐙇'
SignAb118\u{10648}: '𐙈'
SignAb120\u{10649}: '𐙉'
SignA120b\u{1064a}: '𐙊'
SignAb122\u{1064b}: '𐙋'
SignAb123\u{1064c}: '𐙌'
SignAb131a\u{1064d}: '𐙍'
SignAb131b\u{1064e}: '𐙎'
SignA131c\u{1064f}: '𐙏'
SignAb164\u{10650}: '𐙐'
SignAb171\u{10651}: '𐙑'
SignAb180\u{10652}: '𐙒'
SignAb188\u{10653}: '𐙓'
SignAb191\u{10654}: '𐙔'
SignA301\u{10655}: '𐙕'
SignA302\u{10656}: '𐙖'
SignA303\u{10657}: '𐙗'
SignA304\u{10658}: '𐙘'
SignA305\u{10659}: '𐙙'
SignA306\u{1065a}: '𐙚'
SignA307\u{1065b}: '𐙛'
SignA308\u{1065c}: '𐙜'
SignA309a\u{1065d}: '𐙝'
SignA309b\u{1065e}: '𐙞'
SignA309c\u{1065f}: '𐙟'
SignA310\u{10660}: '𐙠'
SignA311\u{10661}: '𐙡'
SignA312\u{10662}: '𐙢'
SignA313a\u{10663}: '𐙣'
SignA313b\u{10664}: '𐙤'
SignA313c\u{10665}: '𐙥'
SignA314\u{10666}: '𐙦'
SignA315\u{10667}: '𐙧'
SignA316\u{10668}: '𐙨'
SignA317\u{10669}: '𐙩'
SignA318\u{1066a}: '𐙪'
SignA319\u{1066b}: '𐙫'
SignA320\u{1066c}: '𐙬'
SignA321\u{1066d}: '𐙭'
SignA322\u{1066e}: '𐙮'
SignA323\u{1066f}: '𐙯'
SignA324\u{10670}: '𐙰'
SignA325\u{10671}: '𐙱'
SignA326\u{10672}: '𐙲'
SignA327\u{10673}: '𐙳'
SignA328\u{10674}: '𐙴'
SignA329\u{10675}: '𐙵'
SignA330\u{10676}: '𐙶'
SignA331\u{10677}: '𐙷'
SignA332\u{10678}: '𐙸'
SignA333\u{10679}: '𐙹'
SignA334\u{1067a}: '𐙺'
SignA335\u{1067b}: '𐙻'
SignA336\u{1067c}: '𐙼'
SignA337\u{1067d}: '𐙽'
SignA338\u{1067e}: '𐙾'
SignA339\u{1067f}: '𐙿'
SignA340\u{10680}: '𐚀'
SignA341\u{10681}: '𐚁'
SignA342\u{10682}: '𐚂'
SignA343\u{10683}: '𐚃'
SignA344\u{10684}: '𐚄'
SignA345\u{10685}: '𐚅'
SignA346\u{10686}: '𐚆'
SignA347\u{10687}: '𐚇'
SignA348\u{10688}: '𐚈'
SignA349\u{10689}: '𐚉'
SignA350\u{1068a}: '𐚊'
SignA351\u{1068b}: '𐚋'
SignA352\u{1068c}: '𐚌'
SignA353\u{1068d}: '𐚍'
SignA354\u{1068e}: '𐚎'
SignA355\u{1068f}: '𐚏'
SignA356\u{10690}: '𐚐'
SignA357\u{10691}: '𐚑'
SignA358\u{10692}: '𐚒'
SignA359\u{10693}: '𐚓'
SignA360\u{10694}: '𐚔'
SignA361\u{10695}: '𐚕'
SignA362\u{10696}: '𐚖'
SignA363\u{10697}: '𐚗'
SignA364\u{10698}: '𐚘'
SignA365\u{10699}: '𐚙'
SignA366\u{1069a}: '𐚚'
SignA367\u{1069b}: '𐚛'
SignA368\u{1069c}: '𐚜'
SignA369\u{1069d}: '𐚝'
SignA370\u{1069e}: '𐚞'
SignA371\u{1069f}: '𐚟'
SignA400DashVas\u{106a0}: '𐚠'
SignA401DashVas\u{106a1}: '𐚡'
SignA402DashVas\u{106a2}: '𐚢'
SignA403DashVas\u{106a3}: '𐚣'
SignA404DashVas\u{106a4}: '𐚤'
SignA405DashVas\u{106a5}: '𐚥'
SignA406DashVas\u{106a6}: '𐚦'
SignA407DashVas\u{106a7}: '𐚧'
SignA408DashVas\u{106a8}: '𐚨'
SignA409DashVas\u{106a9}: '𐚩'
SignA410DashVas\u{106aa}: '𐚪'
SignA411DashVas\u{106ab}: '𐚫'
SignA412DashVas\u{106ac}: '𐚬'
SignA413DashVas\u{106ad}: '𐚭'
SignA414DashVas\u{106ae}: '𐚮'
SignA415DashVas\u{106af}: '𐚯'
SignA416DashVas\u{106b0}: '𐚰'
SignA417DashVas\u{106b1}: '𐚱'
SignA418DashVas\u{106b2}: '𐚲'
SignA501\u{106b3}: '𐚳'
SignA502\u{106b4}: '𐚴'
SignA503\u{106b5}: '𐚵'
SignA504\u{106b6}: '𐚶'
SignA505\u{106b7}: '𐚷'
SignA506\u{106b8}: '𐚸'
SignA508\u{106b9}: '𐚹'
SignA509\u{106ba}: '𐚺'
SignA510\u{106bb}: '𐚻'
SignA511\u{106bc}: '𐚼'
SignA512\u{106bd}: '𐚽'
SignA513\u{106be}: '𐚾'
SignA515\u{106bf}: '𐚿'
SignA516\u{106c0}: '𐛀'
SignA520\u{106c1}: '𐛁'
SignA521\u{106c2}: '𐛂'
SignA523\u{106c3}: '𐛃'
SignA524\u{106c4}: '𐛄'
SignA525\u{106c5}: '𐛅'
SignA526\u{106c6}: '𐛆'
SignA527\u{106c7}: '𐛇'
SignA528\u{106c8}: '𐛈'
SignA529\u{106c9}: '𐛉'
SignA530\u{106ca}: '𐛊'
SignA531\u{106cb}: '𐛋'
SignA532\u{106cc}: '𐛌'
SignA534\u{106cd}: '𐛍'
SignA535\u{106ce}: '𐛎'
SignA536\u{106cf}: '𐛏'
SignA537\u{106d0}: '𐛐'
SignA538\u{106d1}: '𐛑'
SignA539\u{106d2}: '𐛒'
SignA540\u{106d3}: '𐛓'
SignA541\u{106d4}: '𐛔'
SignA542\u{106d5}: '𐛕'
SignA545\u{106d6}: '𐛖'
SignA547\u{106d7}: '𐛗'
SignA548\u{106d8}: '𐛘'
SignA549\u{106d9}: '𐛙'
SignA550\u{106da}: '𐛚'
SignA551\u{106db}: '𐛛'
SignA552\u{106dc}: '𐛜'
SignA553\u{106dd}: '𐛝'
SignA554\u{106de}: '𐛞'
SignA555\u{106df}: '𐛟'
SignA556\u{106e0}: '𐛠'
SignA557\u{106e1}: '𐛡'
SignA559\u{106e2}: '𐛢'
SignA563\u{106e3}: '𐛣'
SignA564\u{106e4}: '𐛤'
SignA565\u{106e5}: '𐛥'
SignA566\u{106e6}: '𐛦'
SignA568\u{106e7}: '𐛧'
SignA569\u{106e8}: '𐛨'
SignA570\u{106e9}: '𐛩'
SignA571\u{106ea}: '𐛪'
SignA572\u{106eb}: '𐛫'
SignA573\u{106ec}: '𐛬'
SignA574\u{106ed}: '𐛭'
SignA575\u{106ee}: '𐛮'
SignA576\u{106ef}: '𐛯'
SignA577\u{106f0}: '𐛰'
SignA578\u{106f1}: '𐛱'
SignA579\u{106f2}: '𐛲'
SignA580\u{106f3}: '𐛳'
SignA581\u{106f4}: '𐛴'
SignA582\u{106f5}: '𐛵'
SignA583\u{106f6}: '𐛶'
SignA584\u{106f7}: '𐛷'
SignA585\u{106f8}: '𐛸'
SignA586\u{106f9}: '𐛹'
SignA587\u{106fa}: '𐛺'
SignA588\u{106fb}: '𐛻'
SignA589\u{106fc}: '𐛼'
SignA591\u{106fd}: '𐛽'
SignA592\u{106fe}: '𐛾'
SignA594\u{106ff}: '𐛿'
SignA595\u{10700}: '𐜀'
SignA596\u{10701}: '𐜁'
SignA598\u{10702}: '𐜂'
SignA600\u{10703}: '𐜃'
SignA601\u{10704}: '𐜄'
SignA602\u{10705}: '𐜅'
SignA603\u{10706}: '𐜆'
SignA604\u{10707}: '𐜇'
SignA606\u{10708}: '𐜈'
SignA608\u{10709}: '𐜉'
SignA609\u{1070a}: '𐜊'
SignA610\u{1070b}: '𐜋'
SignA611\u{1070c}: '𐜌'
SignA612\u{1070d}: '𐜍'
SignA613\u{1070e}: '𐜎'
SignA614\u{1070f}: '𐜏'
SignA615\u{10710}: '𐜐'
SignA616\u{10711}: '𐜑'
SignA617\u{10712}: '𐜒'
SignA618\u{10713}: '𐜓'
SignA619\u{10714}: '𐜔'
SignA620\u{10715}: '𐜕'
SignA621\u{10716}: '𐜖'
SignA622\u{10717}: '𐜗'
SignA623\u{10718}: '𐜘'
SignA624\u{10719}: '𐜙'
SignA626\u{1071a}: '𐜚'
SignA627\u{1071b}: '𐜛'
SignA628\u{1071c}: '𐜜'
SignA629\u{1071d}: '𐜝'
SignA634\u{1071e}: '𐜞'
SignA637\u{1071f}: '𐜟'
SignA638\u{10720}: '𐜠'
SignA640\u{10721}: '𐜡'
SignA642\u{10722}: '𐜢'
SignA643\u{10723}: '𐜣'
SignA644\u{10724}: '𐜤'
SignA645\u{10725}: '𐜥'
SignA646\u{10726}: '𐜦'
SignA648\u{10727}: '𐜧'
SignA649\u{10728}: '𐜨'
SignA651\u{10729}: '𐜩'
SignA652\u{1072a}: '𐜪'
SignA653\u{1072b}: '𐜫'
SignA654\u{1072c}: '𐜬'
SignA655\u{1072d}: '𐜭'
SignA656\u{1072e}: '𐜮'
SignA657\u{1072f}: '𐜯'
SignA658\u{10730}: '𐜰'
SignA659\u{10731}: '𐜱'
SignA660\u{10732}: '𐜲'
SignA661\u{10733}: '𐜳'
SignA662\u{10734}: '𐜴'
SignA663\u{10735}: '𐜵'
SignA664\u{10736}: '𐜶'
SignA701A\u{10740}: '𐝀'
SignA702B\u{10741}: '𐝁'
SignA703D\u{10742}: '𐝂'
SignA704E\u{10743}: '𐝃'
SignA705F\u{10744}: '𐝄'
SignA706H\u{10745}: '𐝅'
SignA707J\u{10746}: '𐝆'
SignA708K\u{10747}: '𐝇'
SignA709L\u{10748}: '𐝈'
SignA709Dash2L2\u{10749}: '𐝉'
SignA709Dash3L3\u{1074a}: '𐝊'
SignA709Dash4L4\u{1074b}: '𐝋'
SignA709Dash6L6\u{1074c}: '𐝌'
SignA710W\u{1074d}: '𐝍'
SignA711X\u{1074e}: '𐝎'
SignA712Y\u{1074f}: '𐝏'
SignA713Omega\u{10750}: '𐝐'
SignA714Abb\u{10751}: '𐝑'
SignA715Bb\u{10752}: '𐝒'
SignA717Dd\u{10753}: '𐝓'
SignA726Eyyy\u{10754}: '𐝔'
SignA732Je\u{10755}: '𐝕'
SignA800\u{10760}: '𐝠'
SignA801\u{10761}: '𐝡'
SignA802\u{10762}: '𐝢'
SignA803\u{10763}: '𐝣'
SignA804\u{10764}: '𐝤'
SignA805\u{10765}: '𐝥'
SignA806\u{10766}: '𐝦'
SignA807\u{10767}: '𐝧'
Methods
impl LinearA[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case